@@ -1,6 +1,3 @@
-// lseek off_t become 64bit 
-#define _FILE_OFFSET_BITS 64
-
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -90,9 +87,10 @@ int32_t SPVM__Sys__IO__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* path = env->get_chars(env, stack, obj_path);
   
+  errno = 0;
   int32_t fd = open(path, flags, mode);
   if (fd == -1) {
-    env->die(env, stack, "[System Error]open failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]open failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -129,9 +127,10 @@ int32_t SPVM__Sys__IO__read(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The $count must be less than the length of the $buf - the $buf_offset", FILE_NAME, __LINE__);
   }
   
+  errno = 0;
   int32_t read_length = read(fd, buf + buf_offset, count);
   if (read_length == -1) {
-    env->die(env, stack, "[System Error]read failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]read failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -169,9 +168,10 @@ int32_t SPVM__Sys__IO__write(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The $count must be less than the length of the $buf - the $buf_offset", FILE_NAME, __LINE__);
   }
   
+  errno = 0;
   int32_t write_length = write(fd, buf + buf_offset, count);
   if (write_length == -1) {
-    env->die(env, stack, "[System Error]write failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]write failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -192,9 +192,10 @@ int32_t SPVM__Sys__IO__lseek(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t whence = stack[2].ival;
 
+  errno = 0;
   int64_t cur_offset = lseek(fd, offset, whence);
   if (cur_offset == -1) {
-    env->die(env, stack, "[System Error]lseek failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]lseek failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -208,9 +209,10 @@ int32_t SPVM__Sys__IO__close(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
 
+  errno = 0;
   int32_t status = close(fd);
   if (status == -1) {
-    env->die(env, stack, "[System Error]close failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]close failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -239,8 +241,9 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = fopen(path, mode);
   
+  errno = 0;
   if (!stream) {
-    env->die(env, stack, "[System Error]fopen failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fopen failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -267,9 +270,10 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* mode = env->get_chars(env, stack, obj_mode);
   
+  errno = 0;
   FILE* stream = fdopen(fd, mode);
   if (!stream) {
-    env->die(env, stack, "[System Error]fdopen failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fdopen failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -291,10 +295,10 @@ int32_t SPVM__Sys__IO__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
+  errno = 0;
   int32_t fd = fileno(stream);
-
   if (fd == -1) {
-    env->die(env, stack, "[System Error]fileno failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fileno failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -518,9 +522,10 @@ int32_t SPVM__Sys__IO__fclose(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
+  errno = 0;
   int32_t status = fclose(stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]fclose failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fclose failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -548,10 +553,11 @@ int32_t SPVM__Sys__IO__fseek(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
 
   int32_t whence = stack[2].ival;
-
+  
+  errno = 0;
   int32_t status = fseek(stream, offset, whence);
   if (status == -1) {
-    env->die(env, stack, "[System Error]fseek failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fseek failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
@@ -570,9 +576,10 @@ int32_t SPVM__Sys__IO__ftell(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
+  errno = 0;
   int64_t offset = ftell(stream);
   if (offset == -1) {
-    env->die(env, stack, "[System Error]ftell failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]ftell failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -591,9 +598,10 @@ int32_t SPVM__Sys__IO__fflush(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
+  errno = 0;
   int32_t status = fflush(stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]fflush failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]fflush failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -612,10 +620,10 @@ int32_t SPVM__Sys__IO__flock(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t operation = stack[1].ival;
   
+  errno = 0;
   int32_t status = flock(fd, operation);
-  
   if (status == -1) {
-    env->die(env, stack, "[System Error]flock failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]flock failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -637,6 +645,8 @@ int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t mode = stack[1].ival;
 
+  errno = 0;
+  
 #ifdef _WIN32
   int32_t status = mkdir(path);
 #else
@@ -644,7 +654,7 @@ int32_t SPVM__Sys__IO__mkdir(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 
   if (status == -1) {
-    env->die(env, stack, "[System Error]mkdir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]mkdir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -673,9 +683,11 @@ int32_t SPVM__Sys__IO__rmdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const char* path = env->get_chars(env, stack, obj_path);
+
+  errno = 0;
   int32_t status = rmdir(path);
   if (status == -1) {
-    env->die(env, stack, "[System Error]rmdir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]rmdir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -693,9 +705,11 @@ int32_t SPVM__Sys__IO__unlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   const char* pathname = env->get_chars(env, stack, obj_pathname);
+
+  errno = 0;
   int32_t status = unlink(pathname);
   if (status == -1) {
-    env->die(env, stack, "[System Error]unlink failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]unlink failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
@@ -724,9 +738,10 @@ int32_t SPVM__Sys__IO__rename(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   const char* newpath = env->get_chars(env, stack, obj_newpath);
   
+  errno = 0;
   int32_t status = rename(oldpath, newpath);
   if (status == -1) {
-    env->die(env, stack, "[System Error]rename failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]rename failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -755,9 +770,11 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
       return env->die(env, stack, "The $size must be less than or equal to the lenght of the $buf", FILE_NAME, __LINE__);
     }
     
+    errno = 0;
     ret_buf = getcwd(buf, size);
   }
   else {
+    errno = 0;
     ret_buf = getcwd(NULL, size);
     if (ret_buf) {
       obj_buf = env->new_string(env, stack, ret_buf, strlen(ret_buf));
@@ -766,7 +783,7 @@ int32_t SPVM__Sys__IO__getcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_buf) {
-    env->die(env, stack, "[System Error]getcwd failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]getcwd failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -800,9 +817,11 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
       return env->die(env, stack, "The $maxlen must be less than or equal to the lenght of the $buffer", FILE_NAME, __LINE__);
     }
     
+    errno = 0;
     ret_buffer = _getdcwd(drive, buffer, maxlen);
   }
   else {
+    errno = 0;
     ret_buffer = _getdcwd(drive, NULL, maxlen);
     if (ret_buffer) {
       obj_buffer = env->new_string(env, stack, ret_buffer, strlen(ret_buffer));
@@ -811,7 +830,7 @@ int32_t SPVM__Sys__IO___getdcwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_buffer) {
-    env->die(env, stack, "[System Error]_getdcwd failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]_getdcwd failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -837,6 +856,8 @@ int32_t SPVM__Sys__IO__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   void* obj_resolved_path = stack[1].oval;
   
+  errno = 0;
+  
   char* ret_resolved_path;
   if (obj_resolved_path) {
     char* resolved_path = (char*)env->get_chars(env, stack, obj_resolved_path);
@@ -851,7 +872,7 @@ int32_t SPVM__Sys__IO__realpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_resolved_path) {
-    env->die(env, stack, "[System Error]realpath failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]realpath failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -878,6 +899,8 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t maxLength = stack[2].ival;
   
+  errno = 0;
+  
   char* ret_absPath;
   if (obj_absPath) {
     char* absPath = (char*)env->get_chars(env, stack, obj_absPath);
@@ -892,7 +915,7 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!ret_absPath) {
-    env->die(env, stack, "[System Error]_fullpath failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]_fullpath failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -905,15 +928,15 @@ int32_t SPVM__Sys__IO___fullpath(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__chdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
-  
   if (!obj_path) {
     return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* path = env->get_chars(env, stack, obj_path);
+  
+  errno = 0;
   int32_t status = chdir(path);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chdir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chdir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -925,18 +948,17 @@ int32_t SPVM__Sys__IO__chdir(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__chmod(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
-  
   if (!obj_path) {
     return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* path = env->get_chars(env, stack, obj_path);
 
   int32_t mode = stack[1].ival;
 
+  errno = 0;
   int32_t status = chmod(path, mode);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chmod failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chmod failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
@@ -952,20 +974,19 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   void* obj_path = stack[0].oval;
-  
   if (!obj_path) {
     return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* path = env->get_chars(env, stack, obj_path);
 
   int32_t owner = stack[1].ival;
 
   int32_t group = stack[2].ival;
 
+  errno = 0;
   int32_t status = chown(path, owner, group);
   if (status == -1) {
-    env->die(env, stack, "[System Error]chown failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]chown failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
@@ -978,22 +999,20 @@ int32_t SPVM__Sys__IO__chown(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__truncate(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_path = stack[0].oval;
-  
   if (!obj_path) {
     return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* path = env->get_chars(env, stack, obj_path);
 
   int64_t length = stack[1].lval;
-  
   if (!(length >= 0)) {
     return env->die(env, stack, "The $length must be less than or equal to 0", FILE_NAME, __LINE__);
   }
 
+  errno = 0;
   int32_t status = truncate(path, length);
   if (status == -1) {
-    env->die(env, stack, "[System Error]truncate failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]truncate failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1010,24 +1029,21 @@ int32_t SPVM__Sys__IO__symlink(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e = 0;
   
   void* obj_oldpath = stack[0].oval;
-  
   if (!obj_oldpath) {
     return env->die(env, stack, "The $oldpath must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* oldpath = env->get_chars(env, stack, obj_oldpath);
 
   void* obj_newpath = stack[1].oval;
-  
   if (!obj_newpath) {
     return env->die(env, stack, "The $newpath must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* newpath = env->get_chars(env, stack, obj_newpath);
   
+  errno = 0;
   int32_t status = symlink(oldpath, newpath);
   if (status == -1) {
-    env->die(env, stack, "[System Error]symlink failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]symlink failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1065,9 +1081,10 @@ int32_t SPVM__Sys__IO__readlink(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The $bufsiz must be less than or equal to the length of the $buf", FILE_NAME, __LINE__);
   }
   
+  errno = 0;
   int32_t placed_length = readlink(path, buf, bufsiz);
   if (placed_length == -1) {
-    env->die(env, stack, "[System Error]readlink failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]readlink failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1084,16 +1101,15 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e = 0;
   
   void* obj_dir = stack[0].oval;
-  
   if (!obj_dir) {
     return env->die(env, stack, "The $dir must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* dir = env->get_chars(env, stack, obj_dir);
 
+  errno = 0;
   DIR* dir_stream = opendir(dir);
   if (!dir_stream) {
-    env->die(env, stack, "[System Error]opendir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]opendir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
@@ -1109,16 +1125,15 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__closedir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirp = stack[0].oval;
-  
   if (!obj_dirp) {
     return env->die(env, stack, "The $dirp object must be defined", FILE_NAME, __LINE__);
   }
-  
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
+  errno = 0;
   int32_t status = closedir(dirp);
   if (status == -1) {
-    env->die(env, stack, "[System Error]closedir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]closedir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1134,17 +1149,15 @@ int32_t SPVM__Sys__IO__readdir(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e = 0;
   
   void* obj_dirp = stack[0].oval;
-  
   if (!obj_dirp) {
     return env->die(env, stack, "The $dirp must be defined", FILE_NAME, __LINE__);
   }
-  
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
   errno = 0;
   struct dirent* dirent = readdir(dirp);
   if (errno != 0) {
-    env->die(env, stack, "[System Error]readdir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]readdir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1178,16 +1191,15 @@ int32_t SPVM__Sys__IO__rewinddir(SPVM_ENV* env, SPVM_VALUE* stack) {
 int32_t SPVM__Sys__IO__telldir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirp = stack[0].oval;
-  
   if (!obj_dirp) {
     return env->die(env, stack, "The $dirp must be defined", FILE_NAME, __LINE__);
   }
-  
   DIR* dirp = env->get_pointer(env, stack, obj_dirp);
   
+  errno = 0;
   int64_t offset = telldir(dirp);
   if (offset == -1) {
-    env->die(env, stack, "[System Error]telldir failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]telldir failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1222,11 +1234,9 @@ int32_t SPVM__Sys__IO__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e = 0;
   
   void* obj_filename = stack[0].oval;
-  
   if (!obj_filename) {
     return env->die(env, stack, "The $filename must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* filename = env->get_chars(env, stack, obj_filename);
 
   void* obj_times = stack[1].oval;
@@ -1238,9 +1248,10 @@ int32_t SPVM__Sys__IO__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_times = NULL;
   }
   
+  errno = 0;
   int32_t status = utime(filename, st_times);
   if (status == -1) {
-    env->die(env, stack, "[System Error]utime failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]utime failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1287,19 +1298,18 @@ int32_t SPVM__Sys__IO__faccessat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
   return env->die(env, stack, "faccessat is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
 #else
   int32_t dirfd = stack[0].ival;
-
-  void* obj_pathname = stack[1].oval;
   
+  void* obj_pathname = stack[1].oval;
   if (!obj_pathname) {
     return env->die(env, stack, "The $pathname must be defined", FILE_NAME, __LINE__);
   }
-  
   const char* pathname = env->get_chars(env, stack, obj_pathname);
   
   int32_t mode = stack[2].ival;
 
   int32_t flags = stack[3].ival;
   
+  errno = 0;
   int32_t status = faccessat(dirfd, pathname, mode, flags);
   
   stack[0].ival = status;
@@ -1322,91 +1332,6 @@ int32_t SPVM__Sys__IO__faccessat(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__IO__stat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  int32_t e = 0;
-  
-  void* obj_path = stack[0].oval;
-  
-  if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
-  }
-  const char* path = env->get_chars(env, stack, obj_path);
-  
-  void* obj_stat = stack[1].oval;
-  
-  if (!obj_stat) {
-    return env->die(env, stack, "The $stat must be defined", FILE_NAME, __LINE__);
-  }
-  
-  struct stat* stat_buf = env->get_pointer(env, stack, obj_stat);
-  
-  int32_t status = stat(path, stat_buf);
-
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-
-int32_t SPVM__Sys__IO__stat(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  SPVM__Sys__IO__stat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
-  if (status == -1) {
-    env->die(env, stack, "[System Error]stat failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__IO__lstat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
-  return env->die(env, stack, "lstat is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
-#else
-
-  int32_t e = 0;
-  
-  void* obj_path = stack[0].oval;
-  
-  if (!obj_path) {
-    return env->die(env, stack, "The $path must be defined", FILE_NAME, __LINE__);
-  }
-  const char* path = env->get_chars(env, stack, obj_path);
-  
-  void* obj_lstat = stack[1].oval;
-  
-  if (!obj_lstat) {
-    return env->die(env, stack, "The $lstat must be defined", FILE_NAME, __LINE__);
-  }
-  
-  struct stat* stat_buf = env->get_pointer(env, stack, obj_lstat);
-  
-  int32_t status = lstat(path, stat_buf);
-  
-  stack[0].ival = status;
-  
-  return 0;
-#endif
-}
-
-int32_t SPVM__Sys__IO__lstat(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  SPVM__Sys__IO__lstat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
-  if (status == -1) {
-    env->die(env, stack, "[System Error]lstat failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef _WIN32
   return env->die(env, stack, "fcntl is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
@@ -1518,13 +1443,12 @@ int32_t SPVM__Sys__IO__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t e;
   
   void* obj_stream = stack[0].oval;
+  if (!obj_stream) {
+    return env->die(env, stack, "The $stream must be defined", FILE_NAME, __LINE__);
+  }
+
   FILE* stream = (FILE*)env->get_pointer(env, stack, obj_stream);
 
-  if (stream == NULL) {
-    stack[0].oval = NULL;
-    return 0;
-  }
-  
   int32_t scope_id = env->enter_scope(env, stack);
   
   int32_t capacity = 80;
@@ -1592,9 +1516,11 @@ int32_t SPVM__Sys__IO__ftruncate(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int64_t length = stack[1].lval;
   
+  errno = 0;
   int32_t status = ftruncate(fd, length);
-  if (status != -1) {
-    env->die(env, stack, "[System Error]ftruncate failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+  
+  if (status == -1) {
+    env->die(env, stack, "[System Error]ftruncate failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1615,7 +1541,7 @@ int32_t SPVM__Sys__IO__ungetc(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = ungetc(c, stream);
   if (status == EOF) {
-    env->die(env, stack, "[System Error]ungetc failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]ungetc failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1630,9 +1556,10 @@ int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
 #else
   int32_t fd = stack[0].ival;
   
+  errno = 0;
   int32_t status = fsync(fd);
-  if (status != -1) {
-    env->die(env, stack, "[System Error]fsync failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+  if (status == -1) {
+    env->die(env, stack, "[System Error]fsync failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
@@ -1642,41 +1569,6 @@ int32_t SPVM__Sys__IO__fsync(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__IO__fstat_raw(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  int32_t e = 0;
-  
-  int32_t fd = stack[0].ival;
-  
-  void* obj_stat = stack[1].oval;
-  
-  if (!obj_stat) {
-    return env->die(env, stack, "The $stat must be defined", FILE_NAME, __LINE__);
-  }
-  
-  struct stat* stat_buf = env->get_pointer(env, stack, obj_stat);
-  
-  int32_t status = fstat(fd, stat_buf);
-
-  stack[0].ival = status;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__IO__fstat(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  SPVM__Sys__IO__fstat_raw(env, stack);
-  
-  int32_t status = stack[0].ival;
-
-  if (status == -1) {
-    env->die(env, stack, "[System Error]fstat failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
@@ -1699,24 +1591,19 @@ int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   FILE* stream = env->get_pointer(env, stack, obj_stream);
   
-  FILE* new_stream = freopen(path, mode, stream);
+  errno = 0;
+  FILE* reopened_stream = freopen(path, mode, stream);
   
-  if (!new_stream) {
-    env->die(env, stack, "[System Error]freopen failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+  if (!reopened_stream) {
+    env->die(env, stack, "[System Error]freopen failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
-  int32_t pointer_fields_length = 1;
-  void* obj_new_stream = env->new_pointer_with_fields_by_name(env, stack, "Sys::IO::FileStream", new_stream, pointer_fields_length, &e, FILE_NAME, __LINE__);
-  if (e) { return e; }
-  
-  stack[0].oval = obj_new_stream;
+  stack[0].oval = obj_stream;
   
   return 0;
 }
 
-int setvbuf(FILE *stream, char *buf, int mode, size_t size);
-
 int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_stream = stack[0].oval;
@@ -1746,10 +1633,10 @@ int32_t SPVM__Sys__IO__setvbuf(SPVM_ENV* env, SPVM_VALUE* stack) {
     }
   }
   
+  errno = 0;
   int32_t status = setvbuf(stream, buf, mode, size);
-  
   if (!(status == 0)) {
-    env->die(env, stack, "[System Error]setvbuf failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]setvbuf failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
